IconGenerator class abstract

A base class to generate icons

Implementers

Constructors

IconGenerator(IconGeneratorContext context, String platformName)
Creates a instance of IconGenerator.

Properties

context → IconGeneratorContext
Contains config
final
hashCode → int
The hash code for this object.
no setterinherited
platformName → String
Name of the platform this IconGenerator is created for.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createIcons() → Future<void>
Creates icons for this platform.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
validateRequirements() → bool
Should return true if this platform has all the requirements to create icons. This runs before to createIcons

Operators

operator ==(Object other) → bool
The equality operator.
inherited