IconGeneratorContext class

Provides easy access to user arguments and configuration

Constructors

IconGeneratorContext({required Config config, required FLILogger logger, required String prefixPath, String? flavor})
Creates an instance of IconGeneratorContext

Properties

config → Config
Contains configuration from configuration file
final
flavor → String?
Value of --flavor flag
final
hashCode → int
The hash code for this object.
no setterinherited
logger → FLILogger
A logger
final
macOSConfig → MacOSConfig?
Shortcut for config.macOSConfig
no setter
prefixPath → String
Value of --prefix flag
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
webConfig → WebConfig?
Shortcut for config.webConfig
no setter
windowsConfig → WindowsConfig?
Shortcut for config.windowsConfig
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited