WebConfig class

The flutter_launcher_icons configuration set for Web

Annotations
  • @JsonSerializable.new(anyMap: true, checked: true)

Constructors

WebConfig({bool generate = false, String? imagePath, String? backgroundColor, String? themeColor})
Creates an instance of WebConfig
const
WebConfig.fromJson(Map json)
Creates WebConfig from json
factory

Properties

backgroundColor → String?
manifest.json's background_color
final
generate → bool
Specifies weather to generate icons for web
final
hashCode → int
The hash code for this object.
no setterinherited
imagePath → String?
Image path for web
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
themeColor → String?
manifest.json's theme_color
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Creates Map from WebConfig
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited