WindowsConfig class

The flutter_launcher_icons configuration set for Windows

Annotations
  • @JsonSerializable.new(anyMap: true, checked: true)

Constructors

WindowsConfig({bool generate = false, String? imagePath, int? iconSize})
Creates a instance of WindowsConfig
const
WindowsConfig.fromJson(Map json)
Creates WindowsConfig from json
factory

Properties

generate → bool
Specifies weather to generate icons for web
final
hashCode → int
The hash code for this object.
no setterinherited
iconSize → int?
Size of the icon to generate
final
imagePath → String?
Image path for web
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
Creates Map from WindowsConfig
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited