InvalidConfigException class

Exception to be thrown whenever we have an invalid configuration

Implemented types

Constructors

InvalidConfigException([String? message])
Constructs instance
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String?
Message for the exception
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited