ContentsImageObject class

Constructors

ContentsImageObject({required String size, required String idiom, required String filename, required String scale, String? platform, List<ContentsImageAppearanceObject>? appearances})

Properties

appearances → List<ContentsImageAppearanceObject>?
final
filename → String
final
hashCode → int
The hash code for this object.
no setterinherited
idiom → String
final
platform → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale → String
final
size → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited