IosIconTemplate class

File to handle the creation of icons for iOS platform

Constructors

IosIconTemplate({required int size, required String name})
constructs an instance of IosIconTemplate

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
suffix of the icon name
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → int
the size of the icon
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited