utils library

Functions

areFSEntiesExist(List<String> paths) → String?
Check if give File or Directory exists at the give paths, if not returns the failed FileSystemEntity path
createDirIfNotExist(String dirPath) → Future<Directory>
Creates Directory in the given dirPath if not exists
createFileIfNotExist(String filePath) → Future<File>
Creates File in the given filePath if not exists
createResizedImage(int iconSize, Image image) → Image
decodeImageFile(String filePath) → Future<Image?>
flavorConfigFile(String flavor) → String
generateError(Exception e, String? error) → String
prettifyJsonEncode(Object? map) → String
Returns a prettified json string
printStatus(String message) → void