WebIconGenerator class

Generates Web icons for flutter

Inheritance

Constructors

WebIconGenerator(IconGeneratorContext context)
Creates an instance of WebIconGenerator.

Properties

context → IconGeneratorContext
Contains config
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
platformName → String
Name of the platform this IconGenerator is created for.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createIcons() → Future<void>
Creates icons for this platform.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
validateRequirements() → bool
Should return true if this platform has all the requirements to create icons. This runs before to createIcons
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited