WebIconTemplate class

A Icon Template for Web

Constructors

WebIconTemplate({required int size, bool maskable = false})
Creates an instance of WebIconTemplate.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
iconFile → String
Icon file name
no setter
iconManifest → Map<String, dynamic>
Icon config for manifest.json
no setter
maskable → bool
Support for maskable icon
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → int
Size of the web icon
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited